summaryrefslogtreecommitdiffstats
path: root/src/core/core.h
diff options
context:
space:
mode:
authorLioncash <mathew1800@gmail.com>2018-10-28 22:37:31 +0100
committerLioncash <mathew1800@gmail.com>2018-10-28 22:44:58 +0100
commitb77f571d20e8e5172159b55e5dd7c6040a6cdef7 (patch)
tree0d4976109f09f481a2ab5138d9a8f88185c69d86 /src/core/core.h
parentMerge pull request #1607 from FearlessTobi/patch-3 (diff)
downloadyuzu-b77f571d20e8e5172159b55e5dd7c6040a6cdef7.tar
yuzu-b77f571d20e8e5172159b55e5dd7c6040a6cdef7.tar.gz
yuzu-b77f571d20e8e5172159b55e5dd7c6040a6cdef7.tar.bz2
yuzu-b77f571d20e8e5172159b55e5dd7c6040a6cdef7.tar.lz
yuzu-b77f571d20e8e5172159b55e5dd7c6040a6cdef7.tar.xz
yuzu-b77f571d20e8e5172159b55e5dd7c6040a6cdef7.tar.zst
yuzu-b77f571d20e8e5172159b55e5dd7c6040a6cdef7.zip
Diffstat (limited to 'src/core/core.h')
-rw-r--r--src/core/core.h31
1 files changed, 23 insertions, 8 deletions
diff --git a/src/core/core.h b/src/core/core.h
index 173be45f8..cfacceb81 100644
--- a/src/core/core.h
+++ b/src/core/core.h
@@ -129,11 +129,11 @@ public:
*/
bool IsPoweredOn() const;
- /**
- * Returns a reference to the telemetry session for this emulation session.
- * @returns Reference to the telemetry session.
- */
- Core::TelemetrySession& TelemetrySession() const;
+ /// Gets a reference to the telemetry session for this emulation session.
+ Core::TelemetrySession& TelemetrySession();
+
+ /// Gets a reference to the telemetry session for this emulation session.
+ const Core::TelemetrySession& TelemetrySession() const;
/// Prepare the core emulation for a reschedule
void PrepareReschedule();
@@ -144,24 +144,36 @@ public:
/// Gets an ARM interface to the CPU core that is currently running
ARM_Interface& CurrentArmInterface();
+ /// Gets an ARM interface to the CPU core that is currently running
+ const ARM_Interface& CurrentArmInterface() const;
+
/// Gets the index of the currently running CPU core
- std::size_t CurrentCoreIndex();
+ std::size_t CurrentCoreIndex() const;
/// Gets the scheduler for the CPU core that is currently running
Kernel::Scheduler& CurrentScheduler();
- /// Gets an ARM interface to the CPU core with the specified index
+ /// Gets the scheduler for the CPU core that is currently running
+ const Kernel::Scheduler& CurrentScheduler() const;
+
+ /// Gets a reference to an ARM interface for the CPU core with the specified index
ARM_Interface& ArmInterface(std::size_t core_index);
+ /// Gets a const reference to an ARM interface from the CPU core with the specified index
+ const ARM_Interface& ArmInterface(std::size_t core_index) const;
+
/// Gets a CPU interface to the CPU core with the specified index
Cpu& CpuCore(std::size_t core_index);
/// Gets a CPU interface to the CPU core with the specified index
const Cpu& CpuCore(std::size_t core_index) const;
- /// Gets the exclusive monitor
+ /// Gets a reference to the exclusive monitor
ExclusiveMonitor& Monitor();
+ /// Gets a constant reference to the exclusive monitor
+ const ExclusiveMonitor& Monitor() const;
+
/// Gets a mutable reference to the GPU interface
Tegra::GPU& GPU();
@@ -230,6 +242,9 @@ private:
/// Returns the currently running CPU core
Cpu& CurrentCpuCore();
+ /// Returns the currently running CPU core
+ const Cpu& CurrentCpuCore() const;
+
/**
* Initialize the emulated system.
* @param emu_window Reference to the host-system window used for video output and keyboard